@@ -8,14 +8,18 @@
 #
 #
 #
-# Intended to be called from configure.ac (via autogen.sh)
+# Intended to be called from meson.
+set -e
 
 VERSION="released"
+RS=".release-status"
 
 [ -d ".git" ] || { echo "$VERSION" && exit 0 ; }
 
-if grep -q -i '^ISRELEASED="yes"' ./configure.ac; then
-	echo "$VERSION"
-else
-	git describe --always --long --dirty --tags
-fi
+. "./$RS"
+
+[ -z "$ISRELEASED" ] && { echo "UNKNOWN" && exit 0 ; }
+[ "$ISRELEASED" = "yes" ] && { echo "$VERSION" && exit 0 ; }
+
+git describe --always --long --dirty --tags
+
